searchNodes=[{"ref":"Abit.html","title":"Abit","type":"module","doc":"Use :atomics as a bit array or as an array of counters with N bits per counter in Elixir. Erlang atomics documentation The Abit module (this module) has functions to use an :atomics as a bit array. The bit array is zero indexed. The Abit.Counter module has functions to create an array of counters and manipulate them."},{"ref":"Abit.html#bit_at/2","title":"Abit.bit_at/2","type":"function","doc":"Returns bit at bit_index in atomic ref. Examples iex&gt; ref = :atomics.new(1, signed: false) iex&gt; ref |&gt; :atomics.put(1, 3) iex&gt; Abit.bit_at(ref, 0) 1 iex&gt; Abit.bit_at(ref, 1) 1 iex&gt; Abit.bit_at(ref, 2) 0"},{"ref":"Abit.html#bit_count/1","title":"Abit.bit_count/1","type":"function","doc":"Returns number of bits in atomics ref. Atomics are 64 bit integers so it is size * 64. Examples iex&gt; ref = :atomics.new(1, signed: false) iex&gt; ref |&gt; Abit.bit_count 64 iex&gt; ref2 = :atomics.new(3, signed: false) iex&gt; ref2 |&gt; Abit.bit_count 192"},{"ref":"Abit.html#bit_position/1","title":"Abit.bit_position/1","type":"function","doc":"Returns position of bit in :atomics. Returns a 2 tuple containing: atomics_index - the index of the atomics array where the bit is located bit_index - the index of the bit in the integer at atomics_index Examples iex&gt; Abit.bit_position(0) {1, 0} iex&gt; Abit.bit_position(11) {1, 11} iex&gt; Abit.bit_position(64) {2, 0}"},{"ref":"Abit.html#hamming_distance/2","title":"Abit.hamming_distance/2","type":"function","doc":"Returns the bitwise hamming distance of two :atomics references. It accepts two :atomics references ref_l and ref_r. Raises ArgumentError if the size of ref_l and ref_r don&#39;t equal. Examples iex&gt; ref_l = :atomics.new(10, signed: false) iex&gt; ref_r = :atomics.new(10, signed: false) iex&gt; Abit.hamming_distance(ref_l, ref_r) 0 iex&gt; ref_l |&gt; :atomics.put(1, 7) iex&gt; Abit.hamming_distance(ref_l, ref_r) 3"},{"ref":"Abit.html#intersect/2","title":"Abit.intersect/2","type":"function","doc":"Bit intersection of atomics using Bitwise AND operator. After the operation ref_a will be returned."},{"ref":"Abit.html#merge/2","title":"Abit.merge/2","type":"function","doc":"Bit merge atomics using Bitwise OR operator. ref_b will be merged into ref_a. After the operation ref_a will be returned."},{"ref":"Abit.html#set_bit/3","title":"Abit.set_bit/3","type":"function","doc":"Sets the bit at bit_index to bit in the atomic ref. Examples iex&gt; ref = :atomics.new(1, signed: false) iex&gt; ref |&gt; :atomics.put(1, 1) iex&gt; ref |&gt; :atomics.get(1) 1 iex&gt; ref |&gt; Abit.set_bit(0, 0) :ok iex&gt; ref |&gt; :atomics.get(1) 0"},{"ref":"Abit.html#set_bits_count/1","title":"Abit.set_bits_count/1","type":"function","doc":"Returns number of bits set to 1 in atomics array ref. Examples iex&gt; ref = :atomics.new(1, signed: false) iex&gt; ref |&gt; :atomics.put(1, 3) iex&gt; Abit.set_bits_count(ref) 2 iex&gt; ref2 = :atomics.new(1, signed: false) iex&gt; Abit.set_bits_count(ref2) 0"},{"ref":"Abit.Bitmask.html","title":"Abit.Bitmask","type":"module","doc":"Functions for working with bits &amp; integer bitmasks."},{"ref":"Abit.Bitmask.html#bit_at/2","title":"Abit.Bitmask.bit_at/2","type":"function","doc":"Returns bit at bit_index in ingteger. Examples iex&gt; Abit.Bitmask.bit_at(2, 0) 0 iex&gt; Abit.Bitmask.bit_at(2, 1) 1 iex&gt; Abit.Bitmask.bit_at(1, 0) 1 iex&gt; Abit.Bitmask.bit_at(0, 0) 0"},{"ref":"Abit.Bitmask.html#hamming_distance/2","title":"Abit.Bitmask.hamming_distance/2","type":"function","doc":"Returns the hamming distance of the bits of two integers. Examples iex&gt; Abit.Bitmask.hamming_distance(1, 0) 1 iex&gt; Abit.Bitmask.hamming_distance(1, 1023) 9 iex&gt; Abit.Bitmask.hamming_distance(1, 1024) 2"},{"ref":"Abit.Bitmask.html#set_bit_at/3","title":"Abit.Bitmask.set_bit_at/3","type":"function","doc":"Sets the bit at bit_index in integer and returns integer with the bit set. Examples iex&gt; Abit.Bitmask.set_bit_at(1, 0, 0) 0 iex&gt; Abit.Bitmask.set_bit_at(0, 0, 1) 1 iex&gt; Abit.Bitmask.set_bit_at(0, 2, 1) 4"},{"ref":"Abit.Bitmask.html#set_bits_count/1","title":"Abit.Bitmask.set_bits_count/1","type":"function","doc":"Returns the count of bits set to 1 in int integer. Examples iex&gt; Abit.Bitmask.set_bits_count(3) 2 iex&gt; Abit.Bitmask.set_bits_count(0) 0 iex&gt; Abit.Bitmask.set_bits_count(1024) 1 iex&gt; Abit.Bitmask.set_bits_count(1023) 10"},{"ref":"Abit.Counter.html","title":"Abit.Counter","type":"module","doc":"Use :atomics as an array of counters with N bits per counter. An :atomics is an array of 64 bit integers so the possible counters are below: Possible counters: bits | unsigned value range | signed value range 2 | 0..3 | -2..1 4 | 0..15 | -8..7 8 | 0..255 | -128..127 16 | 0..65535 | -32768..32767 32 | 0..4294967295 | -2147483648..2147483647 If you need 64 bit counters use: Erlang counters While Erlang :atomics are 1 indexed, Abit.Counter counters are 0 indexed."},{"ref":"Abit.Counter.html#add/3","title":"Abit.Counter.add/3","type":"function","doc":"Increments the value of the counter at index with incr. Returns :ok. Examples iex&gt; c = Abit.Counter.new(10, 8) iex&gt; c |&gt; Abit.Counter.add(7, -12) iex&gt; c |&gt; Abit.Counter.add(7, -12) :ok iex&gt; c |&gt; Abit.Counter.get(7) -24"},{"ref":"Abit.Counter.html#get/2","title":"Abit.Counter.get/2","type":"function","doc":"Returns the value of counter at index. Examples iex&gt; c = Abit.Counter.new(10, 8) iex&gt; c |&gt; Abit.Counter.get(7) 0"},{"ref":"Abit.Counter.html#new/3","title":"Abit.Counter.new/3","type":"function","doc":"Returns a new %Abit.Counter{} struct. size - minimum number of counters to have (if they don&#39;t fit exactly to 64 bit at the end, there will be a few more to fully fill the :atomics. check the :size key in the returned %Abit.Counter{} struct for the exact number of counters.) counters_bit_size - how many bits a counter should use Options signed - whether to have signed or unsigned counters. Defaults to true. Examples Abit.Counter.new(100, 8) # minimum 100 counters; 8 bits signed Abit.Counter.new(10_000, 16, signed: false) # minimum 10_000 counters; 16 bits unsigned"},{"ref":"Abit.Counter.html#put/3","title":"Abit.Counter.put/3","type":"function","doc":"Puts the value into the counter at index. Returns :ok. Examples iex&gt; c = Abit.Counter.new(10, 8) iex&gt; c |&gt; Abit.Counter.put(7, -12) :ok iex&gt; c |&gt; Abit.Counter.get(7) -12"},{"ref":"Abit.Counter.html#t:t/0","title":"Abit.Counter.t/0","type":"type","doc":""}]